package net.sf.javaprinciples.resource;

import net.sf.javaprinciples.core.SystemException;

/**
 * Formats a relative directory and a fixed name.
 */
public class GuidFileResolver extends RootFileResolver
{
    private String filename;

    protected String makeFilename(ResourceIdentifier identifier)
    {
        String guid = identifier.getIdentifier();

        return makeDirectory(guid) + "/" + filename;
    }

    protected String makeDirectory(String guid)
    {
        int firstIndex = guid.indexOf('-');
        if (firstIndex == -1)
        {
            // Missing hyphen
            throw new SystemException(ResourceErrors.RESOURCE_IDENTIFIER_INVALID.name());
        }
        StringBuffer buffer = new StringBuffer();
        String prefix = guid.substring(0, firstIndex);
        String suffix = guid.substring(firstIndex + 1);

        if (prefix.length() % 2 != 0)
        {
            // Must have even number of characters
            throw new SystemException(ResourceErrors.RESOURCE_IDENTIFIER_INVALID.name());
        }

        for (int i = 0; i < prefix.length(); i += 2)
        {
            if (buffer.length() != 0)
            {
                buffer.append("/");
            }
            buffer.append(prefix.charAt(i));
            buffer.append(prefix.charAt(i + 1));
        }
        buffer.append("/");
        buffer.append(suffix);
        return buffer.toString();
    }

    public void setFilename(String filename)
    {
        this.filename = filename;
    }

    public String getFilename()
    {
        return filename;
    }
}
