package net.sf.javaprinciples.resource;

import java.net.URISyntaxException;

import net.sf.javaprinciples.core.SystemException;

/**
 * An extension of the {@link GuidFileResolver} that assumes an incoming resource identifier to
 * be a valid URN, where the identifier is a GUID. (e.g. urn:uuid:af4893e5-00cf-4b40-801c-50ce75544bb8)
 *
 * @author Luka Kruscic
 */
public class GuidUrnFileResolver extends GuidFileResolver
{
    protected String makeFilename(ResourceIdentifier identifier)
    {
        try
        {
            URN urn = new URN(identifier.getIdentifier());
            String guid = urn.getNss();
            return makeDirectory(guid) + "/" + getFilename();
        }
        catch (URISyntaxException e)
        {
            throw new SystemException(ResourceErrors.RESOURCE_IDENTIFIER_INVALID.name());
        }
    }
}