package net.sf.javaprinciples.resource;

import java.io.File;
import java.net.URI;
import java.util.List;
import java.util.StringTokenizer;

/**
 * Determines the root location of the file, but delegates the name to implementations.
 */
public abstract class RootFileResolver implements FileResolver
{
    private URI baseuri;
    private String resourcePath;

    @Override
    public File resolve(ResourceIdentifier identifier)
    {
        File baseuri = makeBaseUri(identifier);
        if (baseuri == null)
        {
            return null;
        }
        String filename = makeFilename(identifier);

        return new File(baseuri, filename);
    }

    protected abstract String makeFilename(ResourceIdentifier identifier);

    /**
     * Create a path to a file ignoring the resourcePath.
     * @param identifier Not null.
     * @return
     */
    protected File makeBaseUri(ResourceIdentifier identifier)
    {
        if (resourcePath == null)
        {
            return new File(baseuri);
        }

        StringTokenizer tokens = new StringTokenizer(resourcePath, "/");

        // Dont consider the last item in the path
        List<String> pathElements = identifier.getPathElements();
        File uri = new File(baseuri);
        uri = uri.getAbsoluteFile();
        for (int i = 0; i < pathElements.size() - 1; i++)
        {
            if (tokens.hasMoreTokens())
            {
                String path = tokens.nextToken();
                if (!path.equals(pathElements.get(i)))
                {
                    return null;
                }
                continue;
            }
            if (pathElements.get(i).equals(".."))
            {
                return null;
            }
            uri = new File(uri, pathElements.get(i));
            if (!uri.exists() || !uri.isDirectory())
            {
                return null;
            }
        }
        return uri;
    }

    public void setBaseuri(URI baseuri)
    {
        this.baseuri = baseuri;
    }

    public URI getBaseuri()
    {
        return baseuri;
    }

    public void setResourcePath(String resourcePath)
    {
        this.resourcePath = resourcePath;
    }

    public String getResourcePath()
    {
        return resourcePath;
    }
}
